@@ -266,7 +266,7 @@ void setActionMenuTextOnly( TDEAction *a, TQString const &suffix )
         TQWidget *w = a->container( i );
         int const id = a->itemId( i );
 
-        if (w->inherits( TQPOPUPMENU_OBJECT_NAME_STRING ))
+        if (w->inherits( "TQPopupMenu" ))
             static_cast<TQPopupMenu*>(w)->changeItem( id, menu_text );
 
         else if (w->inherits( "TDEToolBar" )) {
