@@ -1,10 +1,10 @@
 //Author:    Max Howell <max.howell@methylblue.com>, (C) 2003-4
 //Copyright: See COPYING file that comes with this distribution
 
-#include <kglobal.h>
-#include <kglobalsettings.h>
-#include <kio/job.h>
-#include <klocale.h>
+#include <tdeglobal.h>
+#include <tdeglobalsettings.h>
+#include <tdeio/job.h>
+#include <tdelocale.h>
 
 #include "scan.h"
 #include "progressBox.h"
@@ -16,14 +16,14 @@ ProgressBox::ProgressBox( TQWidget *parent, TQObject *part )
    hide();
 
    setAlignment( TQt::AlignCenter );
-   setFont( KGlobalSettings::fixedFont() );
+   setFont( TDEGlobalSettings::fixedFont() );
    setSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Fixed );
 
    setText( 999999 );
    setMinimumWidth( sizeHint().width() );
 
    connect( &m_timer, TQT_SIGNAL(timeout()), TQT_SLOT(report()) );
-   connect( part, TQT_SIGNAL(started( KIO::Job* )), TQT_SLOT(start()) );
+   connect( part, TQT_SIGNAL(started( TDEIO::Job* )), TQT_SLOT(start()) );
    connect( part, TQT_SIGNAL(completed()), TQT_SLOT(stop()) );
    connect( part, TQT_SIGNAL(canceled( const TQString& )), TQT_SLOT(halt()) );
 }
